@@ -21,17 +21,16 @@ from timers import Timer
 try:
     from bridge import Bridge
 except:
-     print "Failed to import circuits.core.bridge. This probably means we're running in debug mode, and the debug version of the Python socket library is not available. Continuing without."
-     Bridge = None
+    Bridge = None
 
 from pools import Pool
 from workers import Task, Worker
 from debugger import Debugger
 
-__all__ = ("handler",
-        "Event", "Manager",
-        "BaseComponent", "Component",
-        "Value", "future",
-        "Timer", "Bridge", "Debugger",
-        "Task", "Worker", "Pool",
+__all__ = ("handler", "BaseComponent", "Component", "Event",
+        "future", "Pool", "Task", "Worker",
+        "Bridge", "Debugger", "Timer",
+        "Manager",
 )
+
+# hghooks: no-pyflakes
