@@ -56,7 +56,7 @@ from values import Value
 from events import Started, Stopped, Signal
 from events import Error, Success, Failure, Filter, Start, End
 
-TIMEOUT = 1.0 # 1s timeout when no tick functions to process
+TIMEOUT = 0.01 # 10ms timeout when no tick functions to process
 
 class Manager(object):
     """Manager
@@ -83,6 +83,7 @@ class Manager(object):
         self._ticks = set()
 
         self._task = None
+        self._bridge = None
         self._running = False
 
         self.root = self.manager = self
@@ -522,6 +523,8 @@ class Manager(object):
                 and self._task.isAlive()
                 and not current_process() == self._task):
             self._task.terminate()
+        if (self._bridge is not None):
+            self._bridge = None
         self._task = None
         self.tick()
 
@@ -534,11 +537,11 @@ class Manager(object):
             except:
                 etype, evalue, etraceback = _exc_info()
                 self.fire(Error(etype, evalue, format_tb(etraceback)))
-        if self:
-            self._flush()
         else:
             sleep(TIMEOUT) # Nothing to do - Let's not tie up the CUP
 
+        self._flush()
+
     def run(self, log=True, __mode=None, __socket=None):
         if current_thread().getName() == "MainThread":
             if os.name == "posix":
