@@ -12,7 +12,7 @@ from types import IntType, ListType, TupleType
 
 from circuits.core import handler, BaseComponent
 
-from circuits.net.sockets import TCPServer, UNIXServer, Close
+from circuits.net.sockets import TCPServer, UNIXServer
 
 from http import HTTP
 from events import WebEvent
@@ -78,63 +78,46 @@ class BaseServer(BaseComponent):
         else:
             Request.local = Host(self.server.bind, None)
         Request.host = self.host
-        Request.scheme = "https" if self.server.ssl else "http"
+        Request.scheme = "https" if self.server.secure else "http"
 
     @property
     def version(self):
         return SERVER_VERSION
 
     @property
-    def address(self):
+    def host(self):
         if hasattr(self, "server"):
-            if type(self.server.bind) is TupleType:
-                return self.server.bind[0]
-            else:
-                return self.server.bind
+            return self.server.host
 
     @property
     def port(self):
         if hasattr(self, "server"):
-            if type(self.server.bind) is TupleType:
-                return self.server.bind[1]
+            return self.server.port
 
     @property
-    def ssl(self):
-        return self.server.ssl if hasattr(self, "server") else None
+    def secure(self):
+        if hasattr(self, "server"):
+            return self.server.secure
 
     @property
     def scheme(self):
-        return "https" if self.ssl else "http"
-
-    @property
-    def host(self):
-        host = self.address
-
-        if host in ("0.0.0.0", "::", ""):
-            # 0.0.0.0 is INADDR_ANY and :: is IN6ADDR_ANY.
-            # Look up the host name, which should be the
-            # safest thing to spit out in a URL.
-            host = _gethostname()
-
-        ssl = self.ssl
-        port = self.port
-
-        if not ((ssl and port == 443) or (not ssl and port == 80)):
-            if port is not None:
-                host = "%s:%s" % (host, port)
-
-        return host
+        return "https" if self.secure else "http"
 
     @property
     def base(self):
-        host = self.host
+        host = self.host or "0.0.0.0"
+        port = self.port or 80
         scheme = self.scheme
+        secure = self.secure
 
-        return "%s://%s" % (scheme, host)
+        tpl = "%s://%s%s"
 
-    @handler("stopped", target="*")
-    def stopped(self, manager):
-        self.push(Close(), target=self.server)
+        if (port == 80 and not secure) or (port == 443 and secure):
+            port = ""
+        else:
+            port = ":%d" % port
+
+        return tpl % (scheme, host, port)
 
 class Server(BaseServer):
     """Create a Web Server
