@@ -9,12 +9,19 @@ class Server(Component):
         super(Server, self).__init__()
 
         self.data = ""
+        self.host = None
+        self.port = None
         self.ready = False
+        self.closed = False
         self.connected = False
         self.disconnected = False
 
     def ready(self, component):
         self.ready = True
+        self.host, self.port = component._sock.getsockname()
+
+    def closed(self):
+        self.closed = True
 
     def connect(self, sock, *args):
         self.connected = True
