@@ -13,7 +13,6 @@ from circuits.web.wsgi import Gateway
 from circuits.net.sockets import Close
 from circuits.web import Server, Static
 
-BIND = ("127.0.0.1", 8000)
 DOCROOT = os.path.join(os.path.dirname(__file__), "static")
 
 class WebApp(Component):
@@ -21,18 +20,7 @@ class WebApp(Component):
     def __init__(self):
         super(WebApp, self).__init__()
 
-        bind = BIND[0], BIND[1]
-        while True:
-            try:
-                self.server = Server(bind)
-                break
-            except socket.error, e:
-                if e[0] == errno.EADDRINUSE:
-                    bind = bind[0], (bind[1] + 1)
-                else:
-                    raise
-            
-        self.server.register(self)
+        self.server = Server(0).register(self)
 
 def pytest_funcarg__webapp(request):
     return request.cached_setup(
@@ -57,5 +45,4 @@ def setupwebapp(request):
 
 def teardownwebapp(webapp):
     webapp.push(Close(), target=webapp.server)
-    while webapp: pass
     webapp.stop()
