@@ -3,8 +3,6 @@
 import sys
 import math
 
-from circuits import Component, Pool, Task
-
 def isprime(n):
     """Returns True if n is prime and False otherwise"""
     if not isinstance(n, int):
@@ -21,8 +19,5 @@ def isprime(n):
         i += 1
     return True
 
-def sum_primes(n):
-    """Calculates sum of all primes below given integer n"""
-    return sum([x for x in xrange(2, n) if isprime(x)])
-
-x = sum_primes(100)
+N = int(sys.argv[1])
+print sum([x for x in xrange(N) if isprime(x)])
